import { jsx, jsxs } from 'react/jsx-runtime';
import { CashSolid, CurrencyDollarSolid } from '@medusajs/icons';
import { useState, useEffect } from 'react';
import { useMedusa } from 'medusa-react';
import { Container, Heading, Text, Table, Alert, Switch, Label, Input, Button } from '@medusajs/ui';

function LoyaltyRewardsTable() {
  const { client } = useMedusa();
  const [loyaltyDetails, setLoyalty] = useState([]);
  useEffect(() => {
    getLoyaltyDetails();
  }, []);
  const getLoyaltyDetails = async () => {
    client.client.request("GET", `/admin/loyalty`).then((data) => {
      setLoyalty(data.rewards);
    }).catch(() => []);
  };
  return /* @__PURE__ */ jsx("div", { className: "gap-y-6", children: /* @__PURE__ */ jsxs(Container, { className: "p-8 flex flex-col", children: [
    /* @__PURE__ */ jsx(Heading, { level: "h1", children: "Loyalty Rewards" }),
    /* @__PURE__ */ jsx(Text, { size: "base", weight: "regular", children: "Available points for each users" }),
    /* @__PURE__ */ jsxs(Table, { className: "my-4", children: [
      /* @__PURE__ */ jsx(Table.Header, { children: /* @__PURE__ */ jsxs(Table.Row, { children: [
        /* @__PURE__ */ jsx(Table.HeaderCell, { className: "font-bold", children: "Customer Name" }),
        /* @__PURE__ */ jsx(Table.HeaderCell, { className: "font-bold", children: "Email" }),
        /* @__PURE__ */ jsx(Table.HeaderCell, { className: "font-bold", children: "Available points" })
      ] }) }),
      /* @__PURE__ */ jsx(Table.Body, { children: loyaltyDetails.map((loyaltyDetail) => /* @__PURE__ */ jsxs(Table.Row, { children: [
        /* @__PURE__ */ jsx(Table.Cell, { children: loyaltyDetail.user_name }),
        /* @__PURE__ */ jsx(Table.Cell, { children: loyaltyDetail.email }),
        /* @__PURE__ */ jsx(Table.Cell, { children: loyaltyDetail.available_rewards })
      ] })) })
    ] })
  ] }) });
}

const Page$1 = () => {
  return /* @__PURE__ */ jsx(LoyaltyRewardsTable, {});
};
const config$1 = {
  link: {
    label: "Rewards",
    icon: CashSolid
  }
};

var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
function LoyaltySettingsForm() {
  const { client } = useMedusa();
  const [loyaltySetting, setLoyaltySetting] = useState({
    amount: 0,
    is_rewards_active: false
  });
  const [isAlertVisible, setAlert] = useState(false);
  const getLoyaltySettings = async () => {
    client.client.request("GET", `/admin/loyalty-settings`).then((data) => {
      setLoyaltySetting({ amount: data.amount || 0, is_rewards_active: data.is_rewards_active || false });
    }).catch(() => []);
  };
  const saveLoyaltySettings = async () => {
    client.client.request("POST", `/admin/loyalty-settings`, loyaltySetting).then((data) => {
      setAlert(true);
      setTimeout(() => {
        setAlert(false);
      }, 3e3);
    }).catch(() => []);
  };
  useEffect(() => {
    getLoyaltySettings();
  }, []);
  const onToggleChange = (toggleVal) => {
    setLoyaltySetting((prevLoyaltySetting) => __spreadProps(__spreadValues({}, prevLoyaltySetting), {
      is_rewards_active: !prevLoyaltySetting.is_rewards_active
    }));
  };
  const onDataChange = (value) => {
    setLoyaltySetting((prevLoyaltySetting) => __spreadProps(__spreadValues({}, prevLoyaltySetting), {
      amount: value
    }));
  };
  return /* @__PURE__ */ jsxs("div", { className: "gap-y-6", children: [
    isAlertVisible && /* @__PURE__ */ jsx(Alert, { variant: "success", dismissible: true, children: "Successfully saved settings" }),
    /* @__PURE__ */ jsxs(Container, { className: "p-8 flex flex-col my-6", children: [
      /* @__PURE__ */ jsx(Heading, { level: "h1", children: "Loyalty settings" }),
      /* @__PURE__ */ jsx(Text, { size: "base", weight: "regular", children: "Manage loyalty settings" })
    ] }),
    /* @__PURE__ */ jsx(Container, { className: "p-8 flex flex-col my-6", children: /* @__PURE__ */ jsxs("div", { className: "gap-y-4", children: [
      /* @__PURE__ */ jsxs("div", { className: "flex items-center gap-x-2 my-4", children: [
        /* @__PURE__ */ jsx(
          Switch,
          {
            id: "manage-inventory",
            onChange: () => onToggleChange(!loyaltySetting.is_rewards_active),
            checked: loyaltySetting.is_rewards_active
          }
        ),
        /* @__PURE__ */ jsx(Label, { htmlFor: "manage-inventory", children: "Is rewards active" })
      ] }),
      /* @__PURE__ */ jsxs("div", { className: "flex items-center gap-x-2 my-4", children: [
        /* @__PURE__ */ jsx(Label, { children: "Amount per points" }),
        /* @__PURE__ */ jsx(Input, { placeholder: "Enter amount", id: "sales-channel-name", onChange: (event) => onDataChange(parseInt(event.target.value)), value: loyaltySetting.amount })
      ] }),
      /* @__PURE__ */ jsxs("div", { className: "flex place-self-end gap-x-2 my-4", children: [
        /* @__PURE__ */ jsx(Button, { variant: "danger", children: "Cancel" }),
        /* @__PURE__ */ jsx(Button, { onClick: () => saveLoyaltySettings(), children: "Save" })
      ] })
    ] }) })
  ] });
}

const Page = () => {
  return /* @__PURE__ */ jsx(LoyaltySettingsForm, {});
};
const config = {
  card: {
    label: "Loyatlty",
    description: "Loyalty settings",
    icon: CurrencyDollarSolid
  }
};

const entry = {
  identifier: "@shiju-s/valoriz-loyalty-plugin",
  extensions: [
    {
                    Component: Page$1,
                    config: { path: "/loayalty", type: "route", ...config$1 }
                },
    { Component: Page, config: { path: "/custom", type: "setting", ...config } }
  ],
};

export { entry as default };
